Documentation
¶
Index ¶
- Variables
- func AddUserGroup(userGroup models.UserGroup) (int, error)
- func DeleteUserGroup(id int) error
- func GetUserGroup(id int) (*models.UserGroup, error)
- func OnBoardUserGroup(g *models.UserGroup) error
- func PopulateGroup(userGroups []models.UserGroup) ([]int, error)
- func QueryUserGroup(query models.UserGroup) ([]*models.UserGroup, error)
- func UpdateUserGroupName(id int, groupName string) error
Constants ¶
This section is empty.
Variables ¶
var ErrGroupNameDup = errors.New("duplicated user group name")
ErrGroupNameDup ...
Functions ¶
func AddUserGroup ¶
AddUserGroup - Add User Group
func OnBoardUserGroup ¶
OnBoardUserGroup will check if a usergroup exists in usergroup table, if not insert the usergroup and put the id in the pointer of usergroup model, if it does exist, return the usergroup's profile.
func PopulateGroup ¶
PopulateGroup - Return the group ID by given group name. if not exist in Harbor DB, create one
func QueryUserGroup ¶
QueryUserGroup - Query User Group
func UpdateUserGroupName ¶
UpdateUserGroupName ...
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.