Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager interface {
// Add metadatas for project specified by projectID
Add(ctx context.Context, projectID int64, meta map[string]string) error
// Delete metadatas whose keys are specified in parameter meta, if it is absent, delete all
Delete(ctx context.Context, projectID int64, meta ...string) error
// Update metadatas
Update(ctx context.Context, projectID int64, meta map[string]string) error
// Get metadatas whose keys are specified in parameter meta, if it is absent, get all
Get(ctx context.Context, projectID int64, meta ...string) (map[string]string, error)
// List metadata according to the name and value
List(ctx context.Context, name, value string) ([]*models.ProjectMetadata, error)
}
Manager defines the operations that a project metadata manager should implement
Click to show internal directories.
Click to hide internal directories.